@@ -5,7 +5,7 @@
 # pylint: disable=wildcard-import
 # pylint: disable=unused-import
 '''
-    A module of utility methods used for parsing and manipulating data types.
+    A module of utility methods used for database management.
 
     ----------
 
@@ -21,6 +21,19 @@ from colemen_utilities.type_utils.type_utils import *
 from colemen_utilities.database_utils.DatabaseManager import *
 from colemen_utilities.database_utils.TableDataManager import *
 from colemen_utilities.database_utils.TableManager import *
+
+# from colemen_utilities.database_utils.MySQL import *
+import colemen_utilities.database_utils.MySQL as MySQL
+
+
+
+# from colemen_utilities.database_utils.MySQL.MySQLDatabase import MySQLDatabase as MySQL
+# import colemen_utilities.database_utils.MySQL as MySQL
+
+# from colemen_utilities.database_utils.MySQLDatabase import *
+
+
+# import colemen_utilities.database_utils.SelectQuery as selectQuery
 # from colemen_utilities.database_utils.drawio import *
 
 
